@@ -9,6 +9,7 @@ from sanic import Sanic
 from insanic.config import DEFAULT_CONFIG
 from insanic.db import init_db_connection, close_db_connection
 from insanic.http import Request
+from insanic.tasks import init_redis_pool, close_redis_pool
 
 class Application(Sanic):
     def __init__(self, *args: Any, **kwargs: Any):
@@ -46,6 +47,8 @@ class Application(Sanic):
 
     async def boot(self, _application: Application, _loop: AbstractEventLoop) -> None: # pylint: disable=no-self-use
         await init_db_connection()
+        await init_redis_pool()
 
     async def shutdown(self, _application: Application, _loop: AbstractEventLoop) -> None: # pylint: disable=no-self-use
         await close_db_connection()
+        await close_redis_pool()
