@@ -14,6 +14,7 @@ from insanic.commands.migrations import (
 )
 from insanic.commands.routes import RoutesCommand
 from insanic.commands.server import ServerCommand
+from insanic.commands.tasks import TasksQueueCommand
 from insanic.utils import run_async
 
 def load_commands() -> dict[str, AsyncCommand | SyncCommand]:
@@ -21,6 +22,8 @@ def load_commands() -> dict[str, AsyncCommand | SyncCommand]:
         'routes': RoutesCommand(),
         'server': ServerCommand(),
 
+        'tasks_queue': TasksQueueCommand(),
+
         'migrations:apply': MigrationsApplyCommand(),
         'migrations:generate': MigrationsGenerateCommand(),
         'migrations:list': MigrationsListCommand(),
