@@ -1,15 +1,15 @@
 from typing import Any
 
-from insanic.commands import Command, ArgumentParser
+from insanic.commands import SyncCommand, CommandParser
 from insanic.utils import load_application
 
-class ServerCommand(Command):
+class ServerCommand(SyncCommand):
     help = 'Runs application server'
 
-    def add_arguments(self, parser: ArgumentParser) -> None:
+    def add_arguments(self, parser: CommandParser) -> None:
         parser.add_argument('-p', help='Server port')
 
-    def execute(self, *args: Any, **kwargs: Any) -> None:
+    def execute(self, **kwargs: Any) -> None:
         application = load_application()
 
         server_config = {
