@@ -13,7 +13,7 @@ __all__ = (
 class View(HTTPMethodView):
     serializer_class: type[Serializer] | None = None
 
-    def ok_response(self, data: dict, http_status: int = HTTP_STATUS.OK) -> Response:  # pylint: disable=no-self-use
+    def ok_response(self, data: Any, http_status: int = HTTP_STATUS.OK) -> Response:  # pylint: disable=no-self-use
         response_data = { 'status': 'ok', 'data': data }
         return response_json(response_data, status=http_status)
 
